==> wcag-algorithms-1.22.1-sources.jar: org/verapdf/wcag/algorithms/entities/SemanticList.java <==
/**
 * This file is part of veraPDF wcag algorithms, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF wcag algorithms is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF wcag algorithms as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF wcag algorithms as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.wcag.algorithms.entities;

import org.verapdf.wcag.algorithms.entities.enums.SemanticType;
import org.verapdf.wcag.algorithms.entities.lists.ListInterval;

public class SemanticList extends SemanticTextNode {

	private final ListInterval listInterval;

	public SemanticList(SemanticTextNode node, ListInterval listInterval) {
		super(node);
		setSemanticType(SemanticType.LIST);
		this.listInterval = listInterval;
	}

	public int getNumberOfListColumns() {
		return listInterval.getNumberOfColumns();
	}

	public int getNumberOfListItems() {
		return listInterval.getNumberOfListItems();
	}
}

==> wcag-algorithms-1.29.16-sources.jar: org/verapdf/wcag/algorithms/entities/SemanticList.java <==
/**
 * This file is part of veraPDF wcag algorithms, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF wcag algorithms is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF wcag algorithms as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF wcag algorithms as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.wcag.algorithms.entities;

import org.verapdf.wcag.algorithms.entities.enums.SemanticType;
import org.verapdf.wcag.algorithms.entities.lists.ListInterval;

public class SemanticList extends SemanticTextNode {

	private final ListInterval listInterval;

	public SemanticList(SemanticTextNode node, ListInterval listInterval) {
		super(node);
		setSemanticType(SemanticType.LIST);
		this.listInterval = listInterval;
	}

	public int getNumberOfListColumns() {
		return listInterval.getNumberOfColumns();
	}

	public int getNumberOfListItems() {
		return listInterval.getNumberOfListItems();
	}

	public int getNumberOfLists() {
		return listInterval.getNumberOfLists();
	}

	public ListInterval getListInterval() {
		return listInterval;
	}

	public int getNumberOfListItemsAndLists() {
		return listInterval.getNumberOfListItems() + listInterval.getNumberOfLists();
	}
}
